@@ -7,6 +7,8 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
+from typing import Union
+
 from mutagen._util import MutagenError
 
 
@@ -44,7 +46,7 @@ class ID3JunkFrameError(error):
 
 class unsynch(object):
     @staticmethod
-    def decode(value):
+    def decode(value: bytes) -> bytes:
         fragments = bytearray(value).split(b'\xff')
         if len(fragments) > 1 and not fragments[-1]:
             raise ValueError('string ended unsafe')
@@ -59,7 +61,7 @@ class unsynch(object):
         return bytes(bytearray(b'\xff').join(fragments))
 
     @staticmethod
-    def encode(value):
+    def encode(value: bytes) -> bytes:
         fragments = bytearray(value).split(b'\xff')
         for f in fragments[1:]:
             if (not f) or (f[0] >= 0xE0) or (f[0] == 0x00):
@@ -73,7 +75,8 @@ class _BitPaddedMixin(object):
         return self.to_str(self, self.bits, self.bigendian, width, minwidth)
 
     @staticmethod
-    def to_str(value, bits=7, bigendian=True, width=4, minwidth=4):
+    def to_str(value: int, bits: int = 7, bigendian: bool = True,
+               width: int = 4, minwidth: int = 4) -> bytes:
         mask = (1 << bits) - 1
 
         if width != -1:
@@ -101,7 +104,7 @@ class _BitPaddedMixin(object):
         return bytes(bytes_)
 
     @staticmethod
-    def has_valid_padding(value, bits=7):
+    def has_valid_padding(value: Union[int, bytes], bits: int = 7) -> bool:
         """Whether the padding bits are all zero"""
 
         assert bits <= 8
